
Core Developers
---------------

NetworkX development is guided by the following core team:



.. raw:: html

   <div class="team-member">
     <a href="https://github.com/boothby" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars2.githubusercontent.com/u/569654?u=c29b79275293c22fa3c56a06ed04e004465ef331&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @boothby"
           />
        </div>
        Kelly Boothby
     </a>
     <div class="team-member-handle">@boothby</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/camillescott" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars3.githubusercontent.com/u/2896301?u=bd57c546510c131f4f7f41e3999fb8e6e33a2298&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @camillescott"
           />
        </div>
        Camille Scott
     </a>
     <div class="team-member-handle">@camillescott</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/dschult" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars3.githubusercontent.com/u/915037?u=6a27f396c666c5c2172a1cfc7b0d4bbcd0069eed&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @dschult"
           />
        </div>
        Dan Schult
     </a>
     <div class="team-member-handle">@dschult</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/ericmjl" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars0.githubusercontent.com/u/2631566?u=c5d73d769c251a862d7d4bbf1119297d8085c34c&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @ericmjl"
           />
        </div>
        Eric Ma
     </a>
     <div class="team-member-handle">@ericmjl</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/hagberg" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars3.githubusercontent.com/u/187875?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @hagberg"
           />
        </div>
        Aric Hagberg
     </a>
     <div class="team-member-handle">@hagberg</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/jarrodmillman" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars1.githubusercontent.com/u/123428?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @jarrodmillman"
           />
        </div>
        Jarrod Millman
     </a>
     <div class="team-member-handle">@jarrodmillman</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/MridulS" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars1.githubusercontent.com/u/5363860?u=ce5c6e9388d2fd153ebf8b0bb521c928b0813608&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @MridulS"
           />
        </div>
        Mridul Seth
     </a>
     <div class="team-member-handle">@MridulS</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/rossbar" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars2.githubusercontent.com/u/1268991?u=974707b96081a9705f3a239c0773320f353ee02f&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @rossbar"
           />
        </div>
        Ross Barnowski
     </a>
     <div class="team-member-handle">@rossbar</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/stefanv" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars3.githubusercontent.com/u/45071?u=c779b5e06448fbc638bc987cdfe305c7f9a7175e&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @stefanv"
           />
        </div>
        Stefan van der Walt
     </a>
     <div class="team-member-handle">@stefanv</div>
   </div>



Emeritus Developers
-------------------

We thank these previously-active core developers for their contributions to NetworkX.



.. raw:: html

   <div class="team-member">
     <a href="https://github.com/bjedwards" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars0.githubusercontent.com/u/726274?u=e493f38cb65425f6de7a9568ee3802a183deaa8e&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @bjedwards"
           />
        </div>
        Benjamin Edwards
     </a>
     <div class="team-member-handle">@bjedwards</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/chebee7i" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars2.githubusercontent.com/u/326005?u=a5a33cadf55b2fbdd8b033517f97f763563aa72a&v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @chebee7i"
           />
        </div>
        @chebee7i
     </a>
     <div class="team-member-handle">@chebee7i</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/jfinkels" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars0.githubusercontent.com/u/121755?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @jfinkels"
           />
        </div>
        @jfinkels
     </a>
     <div class="team-member-handle">@jfinkels</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/jtorrents" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars2.githubusercontent.com/u/1184374?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @jtorrents"
           />
        </div>
        Jordi Torrents
     </a>
     <div class="team-member-handle">@jtorrents</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/loicseguin" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars3.githubusercontent.com/u/812562?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @loicseguin"
           />
        </div>
        Loïc Séguin-Charbonneau
     </a>
     <div class="team-member-handle">@loicseguin</div>
   </div>


.. raw:: html

   <div class="team-member">
     <a href="https://github.com/ysitu" class="team-member-name">
        <div class="team-member-photo">
           <img
             src="https://avatars2.githubusercontent.com/u/7018196?v=4&s=40"
             loading="lazy"
             alt="Avatar picture of @ysitu"
           />
        </div>
        @ysitu
     </a>
     <div class="team-member-handle">@ysitu</div>
   </div>

